Struct BuildTransactionConfig

#[non_exhaustive]
pub struct BuildTransactionConfig { pub rpc_config: RpcConfig, pub fee_config: FeeConfig, pub compute_config: ComputeConfig, pub min_context_slot: Option<u64>, }
Configuration for building a transaction.

Start with BuildTransactionConfig::default and use the with_* methods to override individual settings. The struct is non-exhaustive so future build options can be added without another breaking release.

use orca_tx_sender::BuildTransactionConfig;

let config = BuildTransactionConfig::default().with_min_context_slot(123);
assert_eq!(config.min_context_slot, Some(123));

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
rpc_config: RpcConfigfee_config: FeeConfigcompute_config: ComputeConfigmin_context_slot: Option<u64>

Minimum bank slot to use for dynamic compute-unit simulation.

Use the context slot returned when fetching recently changed state, such as an address lookup table, so simulation cannot run against an older bank that does not contain that state yet.

Implementations

Source

impl BuildTransactionConfig

pub fn with_rpc_config(self, rpc_config: RpcConfig) -> Self

pub fn with_fee_config(self, fee_config: FeeConfig) -> Self

pub fn with_compute_config(self, compute_config: ComputeConfig) -> Self

pub fn with_min_context_slot(self, min_context_slot: u64) -> Self

Require dynamic compute-unit simulation to use a bank at least as recent as min_context_slot.