#[non_exhaustive]pub struct RpcConfig {
pub url: String,
pub supports_priority_fee_percentile: bool,
pub chain_id: Option<ChainId>,
}Expand description
RPC configuration for connecting to Solana nodes.
Start with RpcConfig::default and use the with_* methods to override
individual settings, or use RpcConfig::new to detect the chain from an
RPC endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: Stringsupports_priority_fee_percentile: boolchain_id: Option<ChainId>Implementations
Sourceimpl RpcConfig
impl RpcConfig
Sourcepub fn with_url(self, url: impl Into<String>) -> Self
pub fn with_url(self, url: impl Into<String>) -> Self
Set the RPC URL without contacting the endpoint or detecting its chain.
Prefer RpcConfig::new when the chain id is not already known.
pub fn with_priority_fee_percentile_support( self, supports_priority_fee_percentile: bool, ) -> Self
pub fn with_chain_id(self, chain_id: ChainId) -> Self
pub async fn new(url: impl Into<String>) -> Result<Self, String>
pub fn client(&self) -> RpcClient
Sourcepub fn is_mainnet(&self) -> bool
pub fn is_mainnet(&self) -> bool
Check if the RPC is connected to Solana mainnet